@@ -1,5 +1,3 @@
-from __future__ import division, unicode_literals
-
 import collections
 import itertools
 import os
@@ -7,6 +5,7 @@ import datetime
 import logging
 from argparse import RawTextHelpFormatter
 import sys
+
 if sys.platform != 'win32':
     import resource
 
@@ -71,34 +70,40 @@ It is possible to force the import of files which weren't downloaded using the
         return parser
 
     def add_arguments(self, parser):
-        parser.add_argument('--force-import-all', action='store_true',
+        parser.add_argument(
+            '--force-import-all', action='store_true',
             default=False, help='Import even if files are up-to-date.'
         ),
-        parser.add_argument('--force-all', action='store_true', default=False,
+        parser.add_argument(
+            '--force-all', action='store_true', default=False,
             help='Download and import if files are up-to-date.'
         ),
-        parser.add_argument('--force-import', action='append', default=[],
+        parser.add_argument(
+            '--force-import', action='append', default=[],
             help='Import even if files matching files are up-to-date'
         ),
-        parser.add_argument('--force', action='append', default=[],
+        parser.add_argument(
+            '--force', action='append', default=[],
             help='Download and import even if matching files are up-to-date'
         ),
         parser.add_argument('--noinsert', action='store_true',
-            default=False,
-            help='Update existing data only'
-        ),
-        parser.add_argument('--hack-translations', action='store_true',
+                            default=False,
+                            help='Update existing data only'
+                            ),
+        parser.add_argument(
+            '--hack-translations', action='store_true',
             default=False,
             help='Set this if you intend to import translations a lot'
         ),
-        parser.add_argument('--keep-slugs', action='store_true',
+        parser.add_argument(
+            '--keep-slugs', action='store_true',
             default=False,
             help='Do not update slugs'
         ),
         parser.add_argument('--progress', action='store_true',
-            default=False,
-            help='Show progress bar'
-        ),
+                            default=False,
+                            help='Show progress bar'
+                            ),
 
     def progress_init(self):
         """Initialize progress bar."""
@@ -136,7 +141,7 @@ It is possible to force the import of files which weren't downloaded using the
         self._clear_identity_maps()
 
         if not os.path.exists(DATA_DIR):
-            self.logger.info('Creating %s' % DATA_DIR)
+            self.logger.info('Creating %s', DATA_DIR)
             os.mkdir(DATA_DIR)
 
         install_file_path = os.path.join(DATA_DIR, 'install_datetime')
@@ -180,20 +185,21 @@ It is possible to force the import of files which weren't downloaded using the
                         force_import = True
 
             if not os.path.exists(install_file_path):
-                self.logger.info('Forced import of %s because data do not seem'
-                        ' to have installed successfuly yet, note that this is'
-                        ' equivalent to --force-import-all.' %
-                        destination_file_name)
+                self.logger.info(
+                    'Forced import of %s because data do not seem'
+                    ' to have installed successfuly yet, note that this is'
+                    ' equivalent to --force-import-all.',
+                    destination_file_name)
                 force_import = True
 
             if downloaded or force_import:
-                self.logger.info('Importing %s' % destination_file_name)
+                self.logger.info('Importing %s', destination_file_name)
 
                 if url in TRANSLATION_SOURCES:
                     if options.get('hack_translations', False):
                         if os.path.exists(translation_hack_path):
                             self.logger.debug(
-                                'Using translation parsed data: %s' %
+                                'Using translation parsed data: %s',
                                 translation_hack_path)
                             continue
 
@@ -248,7 +254,8 @@ It is possible to force the import of files which weren't downloaded using the
             del self._subregion_codes
         self._country_codes = {}
         self._region_codes = collections.defaultdict(dict)
-        self._subregion_codes = collections.defaultdict(dict)
+        self._subregion_codes = collections.defaultdict(
+            lambda: collections.defaultdict(dict))
 
     def _get_country_id(self, country_code2):
         """
@@ -280,11 +287,13 @@ It is possible to force the import of files which weren't downloaded using the
         if region_id not in self._region_codes[country_id]:
             self._region_codes[country_id][region_id] = Region.objects.get(
                 country_id=country_id, geoname_code=region_id).pk
-        if subregion_id not in self._subregion_codes[country_id]:
-            self._subregion_codes[country_id][subregion_id] = \
+
+        if subregion_id not in self._subregion_codes[country_id][region_id]:
+            self._subregion_codes[country_id][region_id][subregion_id] = \
                 SubRegion.objects.get(
-                country_id=country_id, geoname_code=subregion_id).pk
-        return self._subregion_codes[country_id][subregion_id]
+                    region_id=self._region_codes[country_id][region_id],
+                    geoname_code=subregion_id).pk
+        return self._subregion_codes[country_id][region_id][subregion_id]
 
     def country_import(self, items):
         try:
@@ -292,9 +301,10 @@ It is possible to force the import of files which weren't downloaded using the
         except InvalidItems:
             return
 
+        force_insert = False
+        force_update = False
         try:
-            force_insert = False
-            force_update = False
+
             country = Country.objects.get(geoname_id=items[ICountry.geonameid])
             force_update = True
         except Country.DoesNotExist:
@@ -335,9 +345,9 @@ It is possible to force the import of files which weren't downloaded using the
         except InvalidItems:
             return
 
+        force_insert = False
+        force_update = False
         try:
-            force_insert = False
-            force_update = False
             region = Region.objects.get(geoname_id=items[IRegion.geonameid])
             force_update = True
         except Region.DoesNotExist:
@@ -392,8 +402,8 @@ It is possible to force the import of files which weren't downloaded using the
         except InvalidItems:
             return
 
+        force_insert = force_update = False
         try:
-            force_insert = force_update = False
             subregion = SubRegion.objects.filter(
                 geoname_id=items[ISubRegion.geonameid]).first()
             if subregion:
@@ -470,9 +480,9 @@ It is possible to force the import of files which weren't downloaded using the
         except InvalidItems:
             return
 
+        force_insert = False
+        force_update = False
         try:
-            force_insert = False
-            force_update = False
             city = City.objects.get(geoname_id=items[ICity.geonameid])
             force_update = True
         except City.DoesNotExist:
@@ -503,7 +513,7 @@ It is possible to force the import of files which weren't downloaded using the
                 items[ICity.admin1Code],
                 items[ICity.admin2Code]
             )
-        except SubRegion.DoesNotExist:
+        except (SubRegion.DoesNotExist, Region.DoesNotExist):
             subregion_id = None
 
         save = False
@@ -577,12 +587,12 @@ It is possible to force the import of files which weren't downloaded using the
 
     def translation_parse(self, items):
         if not hasattr(self, 'translation_data'):
-            self.country_ids = set(Country.objects.values_list('geoname_id',
-                flat=True))
-            self.region_ids = set(Region.objects.values_list('geoname_id',
-                flat=True))
-            self.city_ids = set(City.objects.values_list('geoname_id',
-                flat=True))
+            self.country_ids = set(Country.objects.values_list(
+                'geoname_id', flat=True))
+            self.region_ids = set(Region.objects.values_list(
+                'geoname_id', flat=True))
+            self.city_ids = set(City.objects.values_list(
+                'geoname_id', flat=True))
 
             self.translation_data = collections.OrderedDict((
                 (Country, {}),
@@ -683,7 +693,7 @@ It is possible to force the import of files which weren't downloaded using the
     def save(self, model, force_insert=False, force_update=False):
         try:
             with transaction.atomic():
-                self.logger.debug('Saving %s' % model.name)
+                self.logger.debug('Saving %s', model.name)
                 model.save(
                     force_insert=force_insert,
                     force_update=force_update
@@ -691,4 +701,4 @@ It is possible to force the import of files which weren't downloaded using the
         except IntegrityError as e:
             # Regarding %r see the https://code.djangoproject.com/ticket/20572
             # Also related to http://bugs.python.org/issue2517
-            self.logger.warning('Saving %s failed: %r' % (model, e))
+            self.logger.warning('Saving %s failed: %r', model, e)
